@@ -5,10 +5,8 @@ Camera calibration module.
 """
 
 from .calib import lst_calibration, load_calibrator_from_config
-from .r0 import CameraR0Calibrator
 
 __all__ = [
     'lst_calibration',
     'load_calibrator_from_config',
-    'CameraR0Calibrator',
 ]
