@@ -1,5 +1,5 @@
 """
-Functions to check the contents ofLST DL1 files and associated muon ring files
+Functions to check the contents of LST DL1 files and associated muon ring files
 """
 
 __all__ = [
@@ -11,41 +11,46 @@ __all__ = [
     'merge_dl1datacheck_files'
 ]
 
-import h5py
 import logging
+import os
+from datetime import datetime
+from multiprocessing import Pool
+from pathlib import Path
+
+import h5py
 import matplotlib.colors as colors
 import matplotlib.dates as dates
 import matplotlib.pyplot as plt
 import matplotlib.ticker as mtick
 import numpy as np
-import os
 import pandas as pd
 import tables
-
 from astropy import units as u
 from astropy.table import Table, vstack
+from ctapipe.containers import EventType
 from ctapipe.coordinates import EngineeringCameraFrame
 from ctapipe.instrument import CameraGeometry
 from ctapipe.io import HDF5TableWriter
 from ctapipe.visualization import CameraDisplay
-from datetime import datetime
+# from lstchain.visualization.bokeh import plot_mean_and_stddev_bokeh
+# from bokeh.models.widgets import Panel
+from matplotlib.backends.backend_pdf import PdfPages
+from scipy.stats import poisson, sem
+
 from lstchain.datachecks.containers import DL1DataCheckContainer
 from lstchain.datachecks.containers import DL1DataCheckHistogramBins
 from lstchain.io.io import dl1_params_lstcam_key
 from lstchain.paths import parse_datacheck_dl1_filename, parse_dl1_filename, \
     run_to_muon_filename, run_to_datacheck_dl1_filename
-# from lstchain.visualization.bokeh import plot_mean_and_stddev_bokeh
-# from bokeh.models.widgets import Panel
-from matplotlib.backends.backend_pdf import PdfPages
-from multiprocessing import Pool
-from pathlib import Path
-from scipy.stats import poisson, sem
 
-def check_dl1(filenames, output_path, max_cores=4, create_pdf=False):
+
+def check_dl1(filenames, output_path, max_cores=4, create_pdf=False, batch=False):
     """
 
     Parameters
     ----------
+    batch: bool, run in batch mode
+    create_pdf: bool, create PDF file
     filenames: string, Path, or a list of them, _sorted_ (by growing subrun
     index). Name(s) of the input DL1 .h5 file(s)
     output_path: directory where output will be written
@@ -90,15 +95,15 @@ def check_dl1(filenames, output_path, max_cores=4, create_pdf=False):
             raise FileNotFoundError
 
     # try to determine which trigger_type tag is more reliable for
-    # identifying interlaved pedestals. We check which one has
+    # identifying interleaved pedestals. We check which one has
     # more values == 32, which is the pedestal tag. The one called
-    # "trigger_type" seems to be the TIB trigger type. The fastest way to do
+    # "trigger_type" is the TIB trigger type. The fastest way to do
     # this for the whole run seems to be using normal pytables:
     trig_tags = {'trigger_type': [], 'ucts_trigger_type': []}
     for filename in filenames:
         with tables.open_file(filename,
                               root_uep='/dl1/event/telescope/parameters') as f:
-            for name in trig_tags.keys():
+            for name in trig_tags:
                 trig_tags[name].extend(f.root.LST_LSTCam.col(name))
     num_pedestals = {'trigger_type':
                          (np.array(trig_tags['trigger_type']) == 32).sum(),
@@ -107,14 +112,7 @@ def check_dl1(filenames, output_path, max_cores=4, create_pdf=False):
     logger.info(f'Number of == 32 (pedestal) trigger tags: {num_pedestals}')
 
     # Choose what source to use for obtaining the trigger type:
-    trigger_source = 'ucts_trigger_type'
-
-    # Commented lines below, because the criterion of who has more "pedestal
-    # tags" (==32) does not seem reliable to indicate which source of the
-    # trigger type is more reliable:
-    #
-    # if num_pedestals['ucts_trigger_type'] > num_pedestals['trigger_type']:
-    #    trigger_source = 'ucts_trigger_type'
+    trigger_source = 'event_type'
 
     # create container for the histograms' binnings, to be saved in the hdf5
     # output file:
@@ -123,7 +121,7 @@ def check_dl1(filenames, output_path, max_cores=4, create_pdf=False):
     # create the dl1_datacheck containers (one per subrun) for the three
     # event types, and add them to the list dl1datacheck:
     with Pool(max_cores) as pool:
-        func_args = [(filename, histogram_binning, trigger_source) for
+        func_args = [(filename, histogram_binning) for
                      filename in filenames]
         dl1datacheck = pool.starmap(process_dl1_file, func_args)
     # NOTE: the above does not seem to improve execution time on Mac OS X.
@@ -132,8 +130,7 @@ def check_dl1(filenames, output_path, max_cores=4, create_pdf=False):
     # or... process the files sequentially:
     # dl1datacheck = list([None]*len(filenames))
     # for i, filename in enumerate(filenames):
-    #     dl1datacheck[i] = process_dl1_file(filename, histogram_binning,
-    #     trigger_source)
+    #     dl1datacheck[i] = process_dl1_file(filename, histogram_binning)
 
     # NOTE: I do not think we may have memory problems, but if needed we could
     # write out the containers as they are produced.
@@ -173,21 +170,19 @@ def check_dl1(filenames, output_path, max_cores=4, create_pdf=False):
     # files in the same directory as the DL1 files (assuming all of them are
     # in the same directory as the first one!)
     if create_pdf:
-        plot_datacheck(datacheck_filename, output_path,
+        plot_datacheck(datacheck_filename, output_path, batch,
                        muons_dir=os.path.dirname(filenames[0]))
 
     return
 
 
-def process_dl1_file(filename, bins, trigger_source='trigger_type'):
+def process_dl1_file(filename, bins):
     """
 
     Parameters
     ----------
     filename: string, or Path, input DL1 .h5 file to be checked
     bins: DL1DataCheckHistogramBins container indicating binning of histograms
-    trigger_source: string, name of one of the trigger tags present in the
-    DL1 file
 
     Returns
     -------
@@ -201,12 +196,6 @@ def process_dl1_file(filename, bins, trigger_source='trigger_type'):
 
     logger = logging.getLogger(__name__)
 
-    # define criteria for detecting flatfield events, since as of 20200418
-    # there is no reliable event tagging for those. We require a minimum
-    # fraction of pixels with a charge above a sufficiently large value:
-    ff_min_pixel_charge_median = 40.
-    ff_max_pixel_charge_stddev = 20.
-
     logger.info(f'Opening file {filename}')
     subrun_index = parse_dl1_filename(os.path.basename(filename)).subrun
 
@@ -221,16 +210,15 @@ def process_dl1_file(filename, bins, trigger_source='trigger_type'):
         Table.read(filename, path='instrument/telescope/optics')
     equivalent_focal_length = \
         optics_description_table['equivalent_focal_length']
-    m2deg = np.rad2deg(u.m/equivalent_focal_length*u.rad)/u.m
+    m2deg = np.rad2deg(u.m / equivalent_focal_length * u.rad) / u.m
 
     with tables.open_file(filename) as file:
         # unfortunately pandas.read_hdf does not seem compatible with
         # 'with... as...' statements
         parameters = pd.read_hdf(filename, key=dl1_params_lstcam_key)
 
-        # convert parameters from meters to degrees:
-        for var in ['r', 'width', 'length']:
-            parameters[var] *= m2deg
+        # convert cog distance to camera center from meters to degrees:
+        parameters['r'] *= m2deg
         # time gradient from ns/m to ns/deg
         parameters['time_gradient'] /= m2deg
 
@@ -245,17 +233,13 @@ def process_dl1_file(filename, bins, trigger_source='trigger_type'):
         # trigger type tags are not reliable. We first identify flatfield events
         # by their looks.
         image = image_table.col('image')
-        flatfield_mask = ((np.median(image, axis=1) >
-                           ff_min_pixel_charge_median) &
-                          (np.std(image, axis=1) <
-                           ff_max_pixel_charge_stddev))
+
+        flatfield_mask = (parameters['event_type'] == EventType.FLATFIELD.value)
         # The same mask should be valid for image_table, since the entry in
         # the two tables correspond one to one.
 
-        # then use trigger_source (name of one of the trigger tags in the DL1
-        # file) to try to identify pedestals on the parameters table (but we
-        # trust better the above empirical identification of flatfield events):
-        pedestal_mask = (parameters[trigger_source] == 32) & ~flatfield_mask
+        pedestal_mask = (parameters['event_type'] ==
+                         EventType.SKY_PEDESTAL.value)
 
         # Now obtain by exclusion the masks for cosmics:
         cosmics_mask = ~(pedestal_mask | flatfield_mask)
@@ -302,16 +286,17 @@ def process_dl1_file(filename, bins, trigger_source='trigger_type'):
         else:
             dl1datacheck_cosmics = None
 
-
         return dl1datacheck_pedestals, dl1datacheck_flatfield, \
                dl1datacheck_cosmics
 
 
-def plot_datacheck(datacheck_filename, out_path=None, muons_dir=None):
+def plot_datacheck(datacheck_filename, out_path=None, batch=False, muons_dir=None):
     """
 
     Parameters
     ----------
+    batch: bool, run in batch mode
+    muons_dir
     datacheck_filename: list of strings, or pathlib.Path, name(s) of .h5
     files produced by the function check_dl1, starting from DL1 event files
     If it is a list of file names, we expect each of the files to correspond to
@@ -361,7 +346,6 @@ def plot_datacheck(datacheck_filename, out_path=None, muons_dir=None):
         # Read the binning of the stored histograms, and the info on
         # the source from which the trigger type info has been read:
         hist_binning = file.root.dl1datacheck.histogram_binning
-        trigger_source = file.root.dl1datacheck.used_trigger_tag[0].decode()
 
         group = file.root.dl1datacheck
         # get the tables for each type of events, check first in each case that
@@ -389,7 +373,7 @@ def plot_datacheck(datacheck_filename, out_path=None, muons_dir=None):
             raise RuntimeError
 
         dl1dcheck_tables = [table_flatfield, table_pedestals, table_cosmics]
-        labels = ['flatfield (guessed)', 'pedestals (from '+trigger_source+')',
+        labels = ['flatfield (guessed)', 'pedestals',
                   'cosmics']
         labels = [x for i, x in enumerate(labels)
                   if dl1dcheck_tables[i] is not None]
@@ -402,21 +386,11 @@ def plot_datacheck(datacheck_filename, out_path=None, muons_dir=None):
                  verticalalignment='center')
         plt.text(0.1, 0.6, 'First shower event UTC: ', fontsize=24,
                  horizontalalignment='left', verticalalignment='center')
-        plt.text(0.1, 0.5, '    UCTS: '+
-                 str(datetime.utcfromtimestamp\
-                         (table_cosmics.col('ucts_time')[0][0])),
-                 fontsize=24, horizontalalignment='left',
-                 verticalalignment='center')
-        plt.text(0.1, 0.43, '    Dragon: '+
-                 str(datetime.utcfromtimestamp\
+        plt.text(0.1, 0.5, '    (from Dragon time): ' +
+                 str(datetime.utcfromtimestamp \
                          (table_cosmics.col('dragon_time')[0][0])),
                  fontsize=24, horizontalalignment='left',
                  verticalalignment='center')
-        plt.text(0.1, 0.36, '    TIB: '+
-                 str(datetime.utcfromtimestamp\
-                         (table_cosmics.col('tib_time')[0][0])),
-                 fontsize=24, horizontalalignment='left',
-                 verticalalignment='center')
         axes.axis('off')
         pdf.savefig()
 
@@ -432,21 +406,23 @@ def plot_datacheck(datacheck_filename, out_path=None, muons_dir=None):
             if len(table.col('subrun_index')) == 1:
                 fmt = 'o'
 
-            axes[1, 0].plot(table.col('subrun_index'), table.col('num_events'),
-                            fmt, label=label)
             # elapsed time: would better to take it always from the cosmics
             # table (will be closer to the true one), but number of entries
             # of tables can be different if e.g. pedestals or flatfield events
             # are missing in some subruns!
             elapsed_t = table.col('elapsed_time')
-            axes[1, 1].plot(table.col('subrun_index'),
+            axes[1, 0].plot(table.col('subrun_index'),
                             table.col('num_events') / elapsed_t, fmt,
                             label=label)
-        axes[1, 0].set_ylabel('number of events')
-        axes[1, 1].set_ylabel('rate (events/s)')
+            axes[1, 1].plot(table.col('subrun_index'),
+                            table.col('num_cleaned_events') /
+                            table.col('num_events'), fmt, label=label)
+
+        axes[1, 0].set_ylabel('rate (events/s)')
+        axes[1, 0].set_yscale('log')
+        axes[1, 1].set_ylabel('Fraction of events surviving cleaning')
         for j in (0, 1):
             axes[1, j].set_xlabel('subrun index')
-            axes[1, j].set_yscale('log')
             axes[1, j].legend(loc='best')
 
         pdf.savefig()
@@ -454,10 +430,9 @@ def plot_datacheck(datacheck_filename, out_path=None, muons_dir=None):
         fig, axes = plt.subplots(nrows=2, ncols=2, figsize=pagesize)
         fig.tight_layout(pad=3.0, h_pad=3.0, w_pad=3.0)
 
-        for time_type in ['ucts_time', 'tib_time', 'dragon_time']:
-            axes[0, 0].plot(table_cosmics.col('sampled_event_ids').flatten(),
-                            table_cosmics.col(time_type).flatten(),
-                            label=time_type)
+        axes[0, 0].plot(table_cosmics.col('sampled_event_ids').flatten(),
+        table_cosmics.col('dragon_time').flatten(),
+        label='dragon_time')
         axes[0, 0].set_xlabel('event id')
         axes[0, 0].set_ylabel('timestamp')
         axes[0, 0].legend(loc='best')
@@ -484,7 +459,7 @@ def plot_datacheck(datacheck_filename, out_path=None, muons_dir=None):
         # regular event intervals. We get the mean per row (typically =subrun):
         mean_dragon_time = np.mean(dragon_time, axis=1)
         mpl_times = np.array([dates.date2num(datetime.utcfromtimestamp(x))
-                                             for x in mean_dragon_time])
+                              for x in mean_dragon_time])
         axes[1, 1].plot_date(mpl_times, alt_deg, fmt=fmt, xdate=True,
                              tz='utc')
         axes[1, 1].set_xlabel('time (UTC)')
@@ -492,19 +467,6 @@ def plot_datacheck(datacheck_filename, out_path=None, muons_dir=None):
         axes[1, 1].yaxis.set_major_formatter(mtick.FormatStrFormatter('%.1f'))
         pdf.savefig()
 
-        fig, axes = plt.subplots(nrows=3, ncols=1, figsize=pagesize)
-        fig.tight_layout(pad=3.0, h_pad=3.0, w_pad=3.0)
-
-        for i, time_type in enumerate(['ucts_time', 'tib_time', 'dragon_time']):
-            axes[i].plot(table_cosmics.col('sampled_event_ids').flatten(),
-                         table_cosmics.col(time_type).flatten(),
-                         label=time_type)
-            axes[i].set_xlabel('event id')
-            axes[i].set_ylabel('timestamp')
-            axes[i].legend(loc='best')
-        pdf.savefig()
-
-
         if table_pedestals is None or len(table_pedestals) == 0:
             write_error_page('pedestals', pagesize)
         else:
@@ -523,7 +485,7 @@ def plot_datacheck(datacheck_filename, out_path=None, muons_dir=None):
                                  ['Pedestal mean charge (p.e.)',
                                   'Pedestal charge std dev (p.e.)',
                                   'PEDESTALS, pixel-wise charge info'],
-                                 pagesize, norm='log')
+                                 pagesize, batch, norm='log')
         pdf.savefig()
 
         if table_flatfield is None or len(table_flatfield) == 0:
@@ -541,9 +503,9 @@ def plot_datacheck(datacheck_filename, out_path=None, muons_dir=None):
             plot_mean_and_stddev(table_flatfield, engineering_geom,
                                  ['charge_mean', 'charge_stddev'],
                                  ['Flat-field mean charge (p.e.)',
-                                 'Flat-field charge std dev (p.e.)',
-                                 'FLATFIELD, pixel-wise charge info'], pagesize,
-                                 norm='log')
+                                  'Flat-field charge std dev (p.e.)',
+                                  'FLATFIELD, pixel-wise charge info'], pagesize,
+                                 batch, norm='log')
         pdf.savefig()
 
         # Displaying and saving of FUTURE bokeh display, not yet active:
@@ -562,7 +524,7 @@ def plot_datacheck(datacheck_filename, out_path=None, muons_dir=None):
             for table in dl1dcheck_tables:
                 contents = np.sum(table.col(hist), axis=0)
                 axes.flatten()[i].hist(bins[:-1], bins, histtype='step',
-                                       weights=contents/contents.sum(),
+                                       weights=contents / contents.sum(),
                                        label=table.name)
             axes.flatten()[i].set_yscale('log')
             axes.flatten()[i].set_xscale('log')
@@ -578,7 +540,7 @@ def plot_datacheck(datacheck_filename, out_path=None, muons_dir=None):
         # Find the thresholds (in pe) for which the event numbers are stored:
         colnames = [name for name in table_cosmics.colnames
                     if name.find('num_pulses_above') == 0]
-        threshold = [int(name[name.find('above_')+6:name.find('_pe')])
+        threshold = [int(name[name.find('above_') + 6:name.find('_pe')])
                      for name in colnames]
 
         for table, tname in zip([table_pedestals, table_cosmics],
@@ -603,7 +565,7 @@ def plot_datacheck(datacheck_filename, out_path=None, muons_dir=None):
             # total number of entries for this event type:
             norm = table.col('num_events').sum()
             if norm > 0:
-                fraction = np.array(pix_events)/norm
+                fraction = np.array(pix_events) / norm
             for i, frac in enumerate(fraction):
                 zscale = 'log' if threshold[i] < 200 and frac.sum() > 0 \
                     else 'lin'
@@ -614,7 +576,8 @@ def plot_datacheck(datacheck_filename, out_path=None, muons_dir=None):
                 cam.add_colorbar(ax=axes.flatten()[i], format='%.0e', pad=0.01)
                 # same range for all cameras:
                 axes.flatten()[i].set_xlim((axes[0, 0].get_xlim()))
-                cam.show()
+                if not batch:
+                    cam.show()
             for i in [1, 2, 4]:
                 axes.flatten()[i].set_ylabel('')
             axes[1, 2].set_xscale('log')
@@ -640,9 +603,9 @@ def plot_datacheck(datacheck_filename, out_path=None, muons_dir=None):
             figb, axesb = plt.subplots(nrows=2, ncols=1, figsize=pagesize)
             figb.tight_layout(pad=3.0, h_pad=3.0, w_pad=3.0)
             figb.suptitle(
-                    table.name.upper() + ', relative frequency of pixel '
-                                         'charges, camera averages',
-                    fontsize='xx-large')
+                table.name.upper() + ', relative frequency of pixel '
+                                     'charges, camera averages',
+                fontsize='xx-large')
             for i, y in enumerate(['num_pulses_above_0010_pe',
                                    'num_pulses_above_0030_pe']):
                 if np.mean(table.col(y), axis=1).max() > 0:
@@ -665,7 +628,7 @@ def plot_datacheck(datacheck_filename, out_path=None, muons_dir=None):
                                  ['Flat-field mean time (ns)',
                                   'Flat-field time std dev (ns)',
                                   'FLATFIELD, pixel-wise pulse time info'],
-                                 pagesize)
+                                 pagesize, batch)
             pdf.savefig()
             plot_mean_and_stddev(table_flatfield, engineering_geom,
                                  ['relative_time_mean',
@@ -674,7 +637,7 @@ def plot_datacheck(datacheck_filename, out_path=None, muons_dir=None):
                                   'Flat-field time std dev (ns)',
                                   'FLATFIELD, pixel-wise pulse time relative '
                                   'to camera mean'],
-                                 pagesize)
+                                 pagesize, batch)
 
         pdf.savefig()
 
@@ -683,7 +646,7 @@ def plot_datacheck(datacheck_filename, out_path=None, muons_dir=None):
                              ['Cosmics mean time (ns)',
                               'Cosmics time std dev (ns)',
                               'COSMICS, pixel-wise pulse time info for pixel '
-                              'charge > 1 p.e.'], pagesize)
+                              'charge > 1 p.e.'], pagesize, batch)
         pdf.savefig()
 
         fig, axes = plt.subplots(nrows=2, ncols=3, figsize=pagesize)
@@ -698,14 +661,16 @@ def plot_datacheck(datacheck_filename, out_path=None, muons_dir=None):
             cam = CameraDisplay(engineering_geom, event_fraction, ax=axes[i, 0],
                                 norm='lin', title=titles[i])
             cam.add_colorbar(ax=axes[i, 0])
-            cam.show()
+            if not batch:
+                cam.show()
             camlog = CameraDisplay(engineering_geom, event_fraction,
                                    ax=axes[i, 1], norm='log', title=titles[i])
             camlog.add_colorbar(ax=axes[i, 1])
             # lines below needed to get all camera displays of equal size:
             axes[i, 0].set_xlim((axes[0, 0].get_xlim()))
             axes[i, 1].set_xlim((axes[0, 0].get_xlim()))
-            cam.show()
+            if not batch:
+                cam.show()
             # select pixels which are not on the edge of the camera:
             pix_inside = np.array([len(neig) == 6 for neig in geom.neighbors])
             # histogram the fraction of image cogs contained in those inner
@@ -714,39 +679,39 @@ def plot_datacheck(datacheck_filename, out_path=None, muons_dir=None):
             gt0 = event_fraction > 0
             axes[i, 2].set_xscale('log')
 
-            nbins = 1001;
+            nbins = 1001
             epb = (events_per_pix[pix_inside & gt0].max() -
-                   events_per_pix[pix_inside & gt0].min()) / (nbins-1)
-            epb = int(epb+1.)
+                   events_per_pix[pix_inside & gt0].min()) / (nbins - 1)
+            epb = int(epb + 1.)
             # make sure the same number of integers in each bin (otherwise we
-            # will get "spikes" in the Poisson distributiopn later.number of
+            # will get "spikes" in the Poisson distribution later.number of
             # bins has to be large to achieve reasonable bin width with linear
             # binning, needed to avoid the spikes.
-            xmin = events_per_pix[pix_inside & gt0].min()-0.5
-            xmax = xmin + (nbins-1)*epb
-            # convert to event fraction:
+            xmin = events_per_pix[pix_inside & gt0].min() - 0.5
+            xmax = xmin + (nbins - 1) * epb
+            #  convert to event fraction:
             xmin /= all_events
             xmax /= all_events
 
-            _, bins, _ = axes[i, 2].\
+            _, bins, _ = axes[i, 2]. \
                 hist(event_fraction[pix_inside & gt0],
                      bins=np.linspace(xmin, xmax, nbins))
-                     #bins=np.logspace(np.log10(xmin), np.log10(xmax), nbins))
+            # bins=np.logspace(np.log10(xmin), np.log10(xmax), nbins))
             # average event content:
-            mu = np.sum(events_per_pix[pix_inside])/pix_inside.sum()
+            mu = np.sum(events_per_pix[pix_inside]) / pix_inside.sum()
             # get distribution of contents according to Poisson, integrating
             # the distribution within the same bins of the histogram above:
-            poiss = np.array([poisson.cdf(x2*all_events, mu) -
-                              poisson.cdf(x1*all_events, mu) for
+            poiss = np.array([poisson.cdf(x2 * all_events, mu) -
+                              poisson.cdf(x1 * all_events, mu) for
                               x1, x2 in zip(bins[:-1], bins[1:])])
             # from probability to number of pixels:
             npixels = poiss * pix_inside.sum()
             # log bin centers:
-            k = np.sqrt(bins[:-1]*bins[1:])
+            k = np.sqrt(bins[:-1] * bins[1:])
             axes[i, 2].plot(k[npixels > 0], npixels[npixels > 0],
                             drawstyle='steps-mid',
                             label='Poisson for uniform density')
-            axes[i, 2].set_ylim(top=1.2*axes[i, 2].get_ylim()[1])
+            axes[i, 2].set_ylim(top=1.2 * axes[i, 2].get_ylim()[1])
             axes[i, 2].legend(loc='best')
             axes[i, 2].set_xlabel('Fraction of events')
             axes[i, 2].set_ylabel('# of pixels (excluding edge pixels)')
@@ -760,11 +725,11 @@ def plot_datacheck(datacheck_filename, out_path=None, muons_dir=None):
         for i, hist in enumerate(histos):
             bins = hist_binning.col(hist)[0]
             # normalize bin content by area of the corresponding ring:
-            ringarea = np.pi*(bins[1:]**2-bins[:-1]**2)*u.deg**2
+            ringarea = np.pi * (bins[1:] ** 2 - bins[:-1] ** 2) * u.deg ** 2
 
             axes[i, 0].hist(bins[:-1], bins,
                             weights=np.sum(table_cosmics.col(hist), axis=0) /
-                            ringarea.value, histtype='step')
+                                    ringarea.value, histtype='step')
             axes[i, 0].set_xlabel('distance (deg)')
             axes[i, 0].set_ylabel('events per deg2')
         axes[0, 0].set_title('cog radial distribution')
@@ -904,7 +869,7 @@ def plot_datacheck(datacheck_filename, out_path=None, muons_dir=None):
         fmt = '-'
         if len(subrun_list) == 1:
             fmt = 'o'
-        axes[0, 0].set_ylim(0, num_rings.max()*1.15)
+        axes[0, 0].set_ylim(0, num_rings.max() * 1.15)
         axes[0, 0].plot(subrun_list, num_rings, fmt, label='all rings in files')
         axes[0, 0].plot(subrun_list, num_contained_rings, fmt,
                         label='contained rings')
@@ -913,7 +878,7 @@ def plot_datacheck(datacheck_filename, out_path=None, muons_dir=None):
 
         muon_rate = num_rings / elapsed_t
         contained_muon_rate = num_contained_rings / elapsed_t
-        axes[0, 1].set_ylim(0, muon_rate.max()*1.15)
+        axes[0, 1].set_ylim(0, muon_rate.max() * 1.15)
         axes[0, 1].plot(subrun_list, muon_rate, fmt, label='all rings in files')
         axes[0, 1].plot(subrun_list, contained_muon_rate, fmt,
                         label='contained rings')
@@ -923,16 +888,16 @@ def plot_datacheck(datacheck_filename, out_path=None, muons_dir=None):
             axes[0, j].set_xlabel('subrun index')
         axes[1, 0].hist(muons_table['ring_containment'],
                         bins=np.linspace(0., 1., 51),
-                        weights=np.ones(len(muons_table))/num_rings.sum())
+                        weights=np.ones(len(muons_table)) / num_rings.sum())
         axes[1, 0].set_xlabel('ring containment')
         binning = np.linspace(0., 1., 31)
         axes[1, 1].hist(muons_table['ring_completeness'],
                         bins=binning, histtype='step',
-                        weights=np.ones(len(muons_table))/num_rings.sum(),
+                        weights=np.ones(len(muons_table)) / num_rings.sum(),
                         label='all rings in files')
         axes[1, 1].hist(contained_muons['ring_completeness'], bins=binning,
                         histtype='step',
-                        weights=np.ones(len(contained_muons))/num_rings.sum(),
+                        weights=np.ones(len(contained_muons)) / num_rings.sum(),
                         label='contained rings')
         axes[1, 1].set_xlabel('ring completeness')
         axes[1, 1].legend(loc='best')
@@ -944,13 +909,13 @@ def plot_datacheck(datacheck_filename, out_path=None, muons_dir=None):
         fig.suptitle('MUON RINGS with containment = 1', fontsize='xx-large')
         fig.tight_layout(rect=[0.0, 0.0, 1.0, 0.97],
                          pad=3.0, h_pad=3.0, w_pad=2.0)
-        axes[0, 0].hist(np.sqrt(contained_muons['ring_center_x']**2. +
-                                contained_muons['ring_center_y']**2.),
+        axes[0, 0].hist(np.sqrt(contained_muons['ring_center_x'] ** 2. +
+                                contained_muons['ring_center_y'] ** 2.),
                         bins=np.linspace(0., 2., 51))
         axes[0, 0].set_xlabel('ring center, distance from camera center (m)')
         axes[0, 0].set_ylabel('number of rings')
         axes[1, 0].plot(contained_muons['impact_parameter'],
-                           contained_muons['ring_completeness'], 'x', alpha=0.5)
+                        contained_muons['ring_completeness'], 'x', alpha=0.5)
         axes[1, 0].set_xlabel('reconstructed impact parameter (m)')
         axes[1, 0].set_ylabel('ring completeness')
         axes[0, 1].plot(contained_muons['ring_radius'],
@@ -975,32 +940,33 @@ def plot_datacheck(datacheck_filename, out_path=None, muons_dir=None):
         fig, axes = plt.subplots(nrows=2, ncols=3, figsize=pagesize)
         fig.suptitle('MUON RINGS with containment = 1', fontsize='xx-large')
         fig.tight_layout(rect=[0.0, 0.0, 1.0, 0.97],
-                         pad=2.0, h_pad=3.0, w_pad=3.0)
-        axes[0, 0].plot(contained_muons['hg_peak_sample'],
-                        contained_muons['lg_peak_sample'], 'x', alpha=0.5)
-        axes[0, 0].set_xlabel('High gain peak sample in R1 waveform')
-        axes[0, 0].set_ylabel('Low gain peak sample in R1 waveform')
+                         pad=3.0, h_pad=3.0, w_pad=2.0)
         binning = np.linspace(-0.5, 38.5, 39)
-        axes[1, 0].hist(contained_muons['hg_peak_sample'], bins=binning,
-                        histtype='step', label='HG')
-        axes[1, 0].hist(contained_muons['lg_peak_sample'], bins=binning,
-                        histtype='step', label='LG')
-        axes[1, 0].set_xlabel('peak sample in R1 waveform')
-        axes[1, 0].set_ylabel('number of rings')
-        axes[1, 0].legend(loc='best')
+        axes[0, 0].hist(contained_muons['hg_peak_sample'], bins=binning,
+                        histtype='step')
+        axes[0, 0].set_xlabel('HG peak sample in R1 waveform')
+        axes[0, 0].set_ylabel('number of rings')
+
+        axes[1, 0].plot(contained_muons['ring_completeness'],
+                        contained_muons['ring_size'] /
+                        contained_muons['ring_radius'], 'x', alpha=0.5)
+        axes[1, 0].set_xlabel('ring completeness')
+        axes[1, 0].set_ylabel('ring light (p.e.) / ring radius (deg)')
+
         axes[0, 1].hist(contained_muons['muon_efficiency'],
                         bins=np.linspace(0., 0.5, 51))
         axes[0, 1].set_xlabel('estimated telescope efficiency for muons')
         axes[0, 1].set_ylabel('number of rings')
+
         axes[1, 1].plot(contained_muons['ring_width'],
                         contained_muons['muon_efficiency'], 'x', alpha=0.5)
         axes[1, 1].set_xlim(0., 0.3)
         axes[1, 1].set_ylim(0., 0.5)
         axes[1, 1].set_xlabel('ring width (deg)')
         axes[1, 1].set_ylabel('estimated telescope efficiency for muons')
+
         axes[0, 2].errorbar(good_subruns, mean_effi, yerr=sem_effi, fmt='o',
                             markersize=3.)
-
         axes[0, 2].set_xlabel('subrun index')
         axes[0, 2].set_ylabel('estimated telescope efficiency for muons')
         axes[0, 2].grid(linewidth=0.3, linestyle=':')
@@ -1047,10 +1013,10 @@ def plot_trigger_types(dchecktables, trigger_name, axes):
     trig_types = np.unique(tt[:, 0])
     num_triggers = np.array([(tt[:, 1][tt[:, 0] == trig]).sum()
                              for trig in trig_types])
-    x = np.arange(2+len(trig_types))
+    x = np.arange(2 + len(trig_types))
     # for better display, leave some space on the sides of the bars:
     y = np.append([0], np.append(num_triggers, [0]))
-    labels = ['']+[str(i) for i in trig_types]+['']
+    labels = [''] + [str(i) for i in trig_types] + ['']
     width = 0.3
     axes.bar(x, y, width)
     axes.set_xticks(x)
@@ -1060,10 +1026,11 @@ def plot_trigger_types(dchecktables, trigger_name, axes):
     axes.set_ylabel('number of events')
 
 
-def plot_mean_and_stddev(table, camgeom, columns, labels, pagesize, norm='lin'):
+def plot_mean_and_stddev(table, camgeom, columns, labels, pagesize, batch=False, norm='lin'):
     """
     Parameters
     ----------
+    batch: bool, run in batch mode
     table:  python table containing pixel-wise information to be displayed
     camgeom: camera geometry
     columns: list of 2 strings, columns of 'table', first one is the mean and
@@ -1106,14 +1073,16 @@ def plot_mean_and_stddev(table, camgeom, columns, labels, pagesize, norm='lin'):
     cam = CameraDisplay(camgeom, mean, ax=axes[0, 0], norm=norm,
                         title=labels[0])
     cam.add_colorbar(ax=axes[0, 0])
-    cam.show()
+    if not batch:
+        cam.show()
     cam = CameraDisplay(camgeom, stddev, ax=axes[1, 0], norm=norm,
                         title=labels[1])
     cam.add_colorbar(ax=axes[1, 0])
     # line below needed to get the top and bottom camera displays of equal size:
     axes[1, 0].set_xlim((axes[0, 0].get_xlim()))
-    cam.show()
-    # plot mean vs. pixe_id and as histogram:
+    if not batch:
+        cam.show()
+    # plot mean vs. pixel_id and as histogram:
     axes[0, 1].plot(camgeom.pix_id, mean)
     axes[0, 1].set_xlabel('Pixel id')
     axes[0, 1].set_ylabel(labels[0])
@@ -1170,7 +1139,7 @@ def merge_dl1datacheck_files(file_list):
 
     first_file_name = file_list[0]
     first_file = tables.open_file(first_file_name)
-    # get run number and build the name of the merged file:
+    #  get run number and build the name of the merged file:
     file = parse_datacheck_dl1_filename(os.path.basename(first_file_name))
     merged_filename = run_to_datacheck_dl1_filename(file.tel_id, file.run,
                                                     None, None)
@@ -1231,7 +1200,7 @@ def merge_dl1datacheck_files(file_list):
                                str(filename))
 
         cosmics.append(file.root.dl1datacheck.cosmics[:])
-        file. close()
+        file.close()
 
     merged_file.close()
 
