@@ -16,7 +16,8 @@ from .io import (
     write_metadata,
     write_subarray_tables,
     read_simu_info_merged_hdf5,
-    write_calibration_data
+    write_calibration_data,
+    HDF5_ZSTD_FILTERS,
 )
 
 standard_config = get_standard_config()
@@ -39,5 +40,6 @@ __all__ = [
     'write_metadata',
     'write_subarray_tables',
     'read_simu_info_merged_hdf5',
-    'write_calibration_data'
+    'write_calibration_data',
+    'HDF5_ZSTD_FILTERS',
 ]
