@@ -25,14 +25,19 @@ from ctapipe.coordinates import CameraFrame
 from . import disp
 
 __all__ = [
+    'add_delta_t_key',
     'alt_to_theta',
     'az_to_phi',
     'cal_cam_source_pos',
     'camera_to_altaz',
     'cartesian_to_polar',
     'clip_alt',
+    'compute_alpha',
+    'compute_theta2',
     'expand_tel_list',
+    'extract_source_position',
     'filter_events',
+    'get_effective_time',
     'get_event_pos_in_camera',
     'impute_pointing',
     'linear_imputer',
@@ -40,21 +45,103 @@ __all__ = [
     'predict_source_position_in_camera',
     'radec_to_camera',
     'reco_source_position_sky',
+    'rotate',
     'sky_to_camera',
     'source_dx_dy',
     'source_side',
-    'unix_tai_to_time',
 ]
 
 # position of the LST1
 location = EarthLocation.from_geodetic(-17.89139 * u.deg, 28.76139 * u.deg, 2184 * u.m)
 obstime = Time('2018-11-01T02:00')
 horizon_frame = AltAz(location=location, obstime=obstime)
-UCTS_EPOCH = Time('1970-01-01T00:00:00', scale='tai', format='isot')
-INVALID_TIME = UCTS_EPOCH
 
 
 log = logging.getLogger(__name__)
+def rotate(flat_object, degree=0, origin=(0, 0)):
+    """
+    Rotate 2D object around given axle
+
+    Parameters:
+    -----------
+    array-like flat_object: 2D object to rotate
+    tuple origin: rotation axle coordinates
+    int degree: rotation angle in degrees
+
+    Returns:
+    --------
+    NDArray with new coordinates
+    """
+    angle = np.deg2rad(degree)
+    rotation_matrix = np.array([[np.cos(angle), -np.sin(angle)],
+                                [np.sin(angle), np.cos(angle)]])
+    rotation_axis_coordinates = np.asarray(origin)
+    res = [(rotation_matrix @ (point.T-rotation_axis_coordinates.T) +
+                       rotation_axis_coordinates.T).T for point in np.atleast_2d(flat_object)]
+    return res
+
+
+def extract_source_position(data, observed_source_name, equivalent_focal_length = 28*u.m):
+    """
+    Extract source position from data
+
+    Parameters:
+    -----------
+    pandas.DataFrame data: input data
+    str observed_source_name: Name of the observed source
+    astropy.units.m equivalent_focal_length: Equivalent focal length of a telescope
+
+    Returns:
+    --------
+    2D array of coordinates of the source in form [(x),(y)] in astropy.units.m
+    """
+    observed_source = SkyCoord.from_name(observed_source_name)
+    obstime = pd.to_datetime(data['dragon_time'], unit='s')
+    pointing_alt = u.Quantity(data['alt_tel'], u.rad, copy=False)
+    pointing_az = u.Quantity(data['az_tel'], u.rad, copy=False)
+    source_pos_camera = radec_to_camera(observed_source, obstime,
+                                        pointing_alt, pointing_az, focal=equivalent_focal_length)
+    source_position = [source_pos_camera.x, source_pos_camera.y]
+    return source_position
+
+
+def compute_theta2(data, source_position, conversion_factor=2.0):
+    """
+    Computes a square of theta (angle from z-axis) from camera frame coordinates
+
+    Parameters:
+    -----------
+    pandas.DataFrame data: Input data
+    2D array (x,y) source_position: Observed source position in astropy.units.m
+    float conversion_factor: Conversion factor (default 0.1/0.05 deg/m)
+
+    Returns:
+    -------
+    Array with `theta2` values
+    """
+    reco_src_x = np.array(data['reco_src_x']) * u.m
+    reco_src_y = np.array(data['reco_src_y']) * u.m
+    return conversion_factor**2 * ((source_position[0] - reco_src_x)**2 +
+                                   (source_position[1] - reco_src_y)**2)
+
+
+def compute_alpha(data):
+    """
+    Computes the angle between the shower major axis and polar angle of the shower centroid
+
+    Parameters:
+    -----------
+    pandas.DataFrame data: Input data
+
+    Returns:
+    --------
+    Array with `alpha` values
+    """
+    # phi and psi range [-np.pi, +np.pi]
+    alpha = np.mod(data['phi'] - data['psi'], np.pi)  # alpha in [0, np.pi]
+    alpha = np.minimum(np.pi - alpha, alpha)  # put alpha in [0, np.pi/2]
+
+    return np.rad2deg(alpha)
 
 
 def alt_to_theta(alt):
@@ -164,7 +251,7 @@ def get_event_pos_in_camera(event, tel):
     Return the position of the source in the camera frame
     Parameters
     ----------
-    event: `ctapipe.containers.DataContainer`
+    event: `ctapipe.containers.ArrayEventContainer`
     tel: `ctapipe.instruement.telescope.TelescopeDescription`
 
     Returns
@@ -436,7 +523,6 @@ def filter_events(events,
     Apply data filtering to a pandas dataframe.
     Each filtering range is applied if the column name exists in the DataFrame so that
     `(events >= range[0]) & (events <= range[1])`
-    If the column name does not exist, the filtering is simply not applied
 
     Parameters
     ----------
@@ -453,9 +539,8 @@ def filter_events(events,
     filter = np.ones(len(events), dtype=bool)
 
     for k in filters.keys():
-        if k in events.columns:
-            filter &= (events[k] >= filters[k][0]) & (events[k] <= filters[k][1])
-
+        filter &= (events[k] >= filters[k][0]) & (events[k] <= filters[k][1])
+        
     if finite_params is not None:
         _finite_params = list(set(finite_params).intersection(list(events.columns)))
         with pd.option_context('mode.use_inf_as_null', True):
@@ -529,22 +614,83 @@ def clip_alt(alt):
     """
     return np.clip(alt, -90.*u.deg, 90.*u.deg)
 
-
-def unix_tai_to_time(timestamp):
+def add_delta_t_key(events):
     """
-    Create an astropy.Time object for timestamps in unix tai format.
-    Unix tai format mean seconds since 1970-01-01T00:00 TAI as opposed
-    to 1970-01-01T00:00 UTC for the usual unix timestamps.
+    Adds the time difference with the previous event to a real data
+    dataframe.
+    Should be only used only with non-filtered data frames,
+    so events are consecutive.
+    Parameters
+    ----------
+    events: pandas DataFrame of dl1 events
+
+    Returns
+    -------
+    events: pandas DataFrame of dl1 events with delta_t
     """
-    scalar = np.isscalar(timestamp)
 
-    timestamp = u.Quantity(timestamp, u.s, ndmin=1)
-    invalid = ~np.isfinite(timestamp)
-    timestamp[invalid] = 0
+    # Get delta t of real data and add it to the data frame
+    if 'dragon_time' in events.columns:
+        time= np.array(events.dragon_time)
+        delta_t = np.insert(np.diff(time),0,0)
+        events['delta_t'] = delta_t
+    return events
 
-    t = UCTS_EPOCH + timestamp
+def get_effective_time(events):
+    """
+    Calculate the effective observation time of a set of real data events
+    from a sky observation. delta_t (s) must be the time elapsed from the
+    previous *triggered* event, regardless of whether the list of events
+    contains all triggered events or not. It can be a list only of events
+    which e.g. have valid image parameters. Besides delta_t, each event must
+    have dragon_time, a timestamp (s)
 
-    if scalar:
-        return t[0]
+    Parameters
+    ----------
+    events: pandas DataFrame or astropy.table.QTable
+    If a dataframe, units are assumed to be seconds
 
-    return t
+    Returns
+    -------
+    t_eff: astropy Quantity (in seconds, if input has no units)
+    t_elapsed: astropy Quantity (ditto)
+    """
+    timestamp = np.array(events['dragon_time'])
+    delta_t = np.array(events['delta_t'])
+
+    if not isinstance(timestamp, u.Quantity):
+        timestamp *= u.s
+    if not isinstance(delta_t, u.Quantity):
+        delta_t *= u.s
+
+    # time differences between the events in the table (which in general are
+    # NOT all triggered events):
+    time_diff = np.diff(timestamp)
+
+    # elapsed time: sum of those time differences, excluding large ones which
+    # might indicate the DAQ was stopped (e.g. if the table contains more
+    # than one run). We set 0.1 s as limit to decide a "break" occurred:
+    t_elapsed = np.sum(time_diff[time_diff<0.1*u.s])
+
+    # delta_t is the time elapsed since the previous triggered event.
+    # We exclude the null values that might be set for the first even in a file.
+    delta_t = delta_t[delta_t>0.]
+
+    # dead time per event (minimum observed delta_t, ):
+    dead_time = np.amin(delta_t)
+
+    # Estimate the "true external rate", i.e. what we would see in absence of
+    # dead time. For a Poisson process with fixed dead time per event,
+    # it can be shown that the expected value of delta_t is
+    # <delta_t> = dead_time + 1/rate
+    # Note that the formula is not strictly correct if we have interleaved
+    # events (pedestal and flatfield) at regular intervals, because the
+    # delta_t will never be larger than the time between interleaved
+    # events. But this truncation would hardly be noticeable for the typical
+    # cosmics rates, and 200 Hz of interleaved events.
+
+    rate = 1/(np.mean(delta_t) - dead_time)
+
+    t_eff = t_elapsed / (1 + rate*dead_time)
+
+    return t_eff, t_elapsed
