@@ -25,15 +25,13 @@ def test_overlay_disp_vector():
     overlay_disp_vector(display, disp, hillas)
 
 
-
-def test_display_dl1_event():
-    from ctapipe.io import event_source, EventSeeker
-    from lstchain.tests.test_lstchain import mc_gamma_testfile
+def test_display_dl1_event(mc_gamma_testfile):
+    from ctapipe.io import EventSource, EventSeeker
     from ctapipe.calib import CameraCalibrator
 
-    source = event_source(mc_gamma_testfile, back_seekable=True)
+    source = EventSource(mc_gamma_testfile, back_seekable=True)
     seeker = EventSeeker(source)
-    event = seeker[11]  # event 11 has telescopes 1 and 4 with data
+    event = seeker.get_event_index(11)  # event 11 has telescopes 1 and 4 with data
     CameraCalibrator(subarray=source.subarray)(event)
     display_dl1_event(event, source.subarray.tel[1].camera.geometry, tel_id=1)
     display_dl1_event(event, source.subarray.tel[4].camera.geometry, tel_id=4)
